netapp_ontap.resources.bgp_peer_group API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.bgp_peer_group`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

The following operations are supported:

- Creation: POST network/ip/bgp/peer-groups
- Collection Get: GET network/ip/bgp/peer-groups
- Instance Get: GET network/ip/bgp/peer-groups/{uuid}
- Instance Patch: PATCH network/ip/bgp/peer-groups/{uuid}
- Instance Delete: DELETE network/ip/bgp/peer-groups/{uuid}

## Retrieving network BGP sessions information

The IP BGP peer-groups GET API retrieves and displays relevant information pertaining to the BGP peer-groups configured in the cluster. The response can contain a list of multiple BGP peer-groups or a specific peer-group. Each BGP peer-group represents a BGP session configured between a local interface and a peer router.

## Examples

### Retrieving all BGP peer-groups in the cluster

The following example shows the list of all BGP peer-groups configured in a cluster.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import BgpPeerGroup

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(BgpPeerGroup.get_collection()))

Try it out

    [
        BgpPeerGroup({"uuid": "5f22ae9d-87b2-11e9-a3a6-005056bb81a4", "name": "pg1"}),
        BgpPeerGroup({"uuid": "5fd08be3-87b2-11e9-952f-005056bb2170", "name": "pg2"}),
    ]

### Retrieving a specific BGP peer-group

The following example shows the response when a specific BGP peer-group is requested. The system returns an error when there is no peer-group with the requested UUID.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import BgpPeerGroup

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = BgpPeerGroup(uuid="5fd08be3-87b2-11e9-952f-005056bb2170")
        resource.get()
        print(resource)

Try it out

    BgpPeerGroup(
        {
            "ipspace": {
                "uuid": "84fd3375-879a-11e9-a3a6-005056bb81a4",
                "_links": {
                    "self": {
                        "href": "/api/network/ipspaces/84fd3375-879a-11e9-a3a6-005056bb81a4"
                    }
                },
                "name": "Default",
            },
            "uuid": "5fd08be3-87b2-11e9-952f-005056bb2170",
            "peer": {"address": "10.10.10.1", "asn": 65501},
            "local": {
                "port": {
                    "uuid": "f8ff73de-879a-11e9-952f-005056bb2170",
                    "name": "e0h",
                    "node": {"name": "node1"},
                },
                "interface": {
                    "uuid": "5e76a305-87b2-11e9-952f-005056bb2170",
                    "ip": {"address": "10.10.10.2"},
                    "name": "bgp2",
                },
            },
            "name": "pg2",
            "state": "up",
        }
    )

### Retrieving specific fields and limiting the output using filters

The following example shows the response when a filter is applied (location.port.node.name=node1) and only certain fields are requested. Filtered fields are in the output in addition to the default fields and requested fields.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import BgpPeerGroup

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(
            list(
                BgpPeerGroup.get_collection(
                    fields="local.interface.ip,peer", **{"local.port.node.name": "node1"}
                )
            )
        )

Try it out

    [
        BgpPeerGroup(
            {
                "uuid": "5f22ae9d-87b2-11e9-a3a6-005056bb81a4",
                "peer": {"address": "10.10.10.2", "asn": 65501},
                "local": {
                    "port": {"node": {"name": "node1"}},
                    "interface": {"ip": {"address": "10.10.10.1"}},
                },
                "name": "pg1",
            }
        )
    ]

## Creating a BGP peer-group

The BGP peer-group POST API is used to create a peer-group as shown in the following examples.

## Examples

### Creating a BGP peer-group with an existing interface

The following example shows how to create a BGP peer-group between an existing interface "bgp1" and peer router with the address "10.10.10.10". The local interface "bgp1" needs to support the management-bgp service, otherwise the system returns an error.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import BgpPeerGroup

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = BgpPeerGroup()
        resource.name = "newPg"
        resource.ipspace.name = "Default"
        resource.local.interface.name = "bgp1"
        resource.peer.address = "10.10.10.10"
        resource.post(hydrate=True)
        print(resource)

Try it out

    BgpPeerGroup(
        {
            "ipspace": {"name": "Default"},
            "uuid": "e3faacc6-87cb-11e9-a3a6-005056bb81a4",
            "peer": {"address": "10.10.10.10"},
            "local": {"interface": {"name": "bgp1"}},
            "name": "newPg",
        }
    )

### Creating a BGP peer-group and provisioning a new local interface

The following example shows how to create a BGP peer-group with any local interface. If the local interface doesn't exist, the system will create it first before creating the peer-group.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import BgpPeerGroup

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = BgpPeerGroup()
        resource.name = "newPg1"
        resource.ipspace.name = "Default"
        resource.local.interface.name = "newlif"
        resource.local.ip.address = "9.9.9.9"
        resource.local.ip.netmask = "24"
        resource.local.port.name = "e0f"
        resource.local.port.node.name = "node1"
        resource.peer.address = "10.10.10.10"
        resource.post(hydrate=True)
        print(resource)

Try it out

    BgpPeerGroup(
        {
            "ipspace": {"name": "Default"},
            "uuid": "c292f069-8872-11e9-a3a6-005056bb81a4",
            "peer": {"address": "10.10.10.10"},
            "local": {
                "port": {"name": "e0f", "node": {"name": "node1"}},
                "interface": {"name": "newlif"},
            },
            "name": "newPg1",
        }
    )

## Updating BGP peer-groups

The BGP peer-groups PATCH API is used to update attributes of a peer-group.

## Examples

### Updating the peer router address

The following example shows how the PATCH request changes the peer router IP address.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import BgpPeerGroup

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = BgpPeerGroup(uuid="80d271c9-1f43-11e9-803e-005056a7646a")
        resource.peer.address = "10.10.10.20"
        resource.patch()

### Updating the peer-group to a new name

The following example shows how the PATCH request renames the peer-group.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import BgpPeerGroup

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = BgpPeerGroup(uuid="80d271c9-1f43-11e9-803e-005056a7646a")
        resource.name = "NewName"
        resource.patch()

## Deleting BGP peer-groups

The BGP peer-groups DELETE API is used to delete an BGP peer-group.

## Example

### Deleting a BGP peer-group

The following DELETE request deletes a BGP peer-group.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import BgpPeerGroup

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = BgpPeerGroup(uuid="80d271c9-1f43-11e9-803e-005056a7646a")
        resource.delete()

## Classes

`class BgpPeerGroup (*args, **kwargs)`

  A BGP peer group between a local network interface and a router, for the purpose of announcing VIP interface locations for SVMs in this IPspace.

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves the details of all BGP peer groups for VIP.

    ### Related ONTAP Commands

    - `network bgp peer-group show`

    ### Learn more

    - `DOC /network/ip/bgp/peer-groups`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection(*args, body: typing.Union = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes a BGP peer group for VIP.

    ### Related ONTAP commands

    - `network bgp peer-group delete`

    ### Learn more

    - `DOC /network/ip/bgp/peer-groups`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves the details of all BGP peer groups for VIP.

    ### Related ONTAP Commands

    - `network bgp peer-group show`

    ### Learn more

    - `DOC /network/ip/bgp/peer-groups`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves the details of all BGP peer groups for VIP.

    ### Related ONTAP Commands

    - `network bgp peer-group show`

    ### Learn more

    - `DOC /network/ip/bgp/peer-groups`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection(body: dict, *args, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates a BGP peer group for VIP.

    ### Related ONTAP commands

    - `network bgp peer-group modify`
    - `network bgp peer-group rename`

    ### Learn more

    - `DOC /network/ip/bgp/peer-groups`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete(self, body: typing.Union = None, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Deletes a BGP peer group for VIP.

    ### Related ONTAP commands

    - `network bgp peer-group delete`

    ### Learn more

    - `DOC /network/ip/bgp/peer-groups`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves details of a BGP peer group for VIP.

    ### Related ONTAP commands

    - `network bgp peer-group show`

    ### Learn more

    - `DOC /network/ip/bgp/peer-groups`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def patch(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Updates a BGP peer group for VIP.

    ### Related ONTAP commands

    - `network bgp peer-group modify`
    - `network bgp peer-group rename`

    ### Learn more

    - `DOC /network/ip/bgp/peer-groups`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Creates a new BGP peer group for VIP. Multipath-routing is turned on cluster-wide automatically if the peer group being created results in multiple paths being available for an existing or future VIP interface.

    ### Required properties

    - `name` - Name of the peer-group to create.
    - `ipspace.name` or `ipspace.uuid`
    - Required with local.interface.name to identify a local interface
    - Optional when local.interface.uuid is specified
    - `local.interface.uuid` or `local.interface.name`
    - Required when specifying an existing local interface.
    - `local.interface.name`, `local.ip` and `local.port`
    - Required to create a new local interface.
    - `peer.address` - IP address of the peer router

    ### Related ONTAP commands

    - `network bgp peer-group create`

    ### Learn more

    - `DOC /network/ip/bgp/peer-groups`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class BgpPeerGroupSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the BgpPeerGroup object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `ipspace GET POST`

    The ipspace field of the bgp_peer_group.

  `local GET POST PATCH`

    The local field of the bgp_peer_group.

  `name GET POST PATCH`

    Name of the peer group

    Example: bgpv4peer

  `peer GET POST PATCH`

    The peer field of the bgp_peer_group.

  `state GET`

    State of the peer group

    Valid choices:

    - up
    - down
  `uuid GET`

    UUID of the peer group

    Example: 1cd8a442-86d1-11e0-ae1c-123478563412